@@ -41,7 +41,7 @@ fn return_error_page(
     let html_to_replace_single = format!("<div id='{}'>", root_id);
     let html_replacement = format!(
         // We give the content a specific ID so that it can be hydrated properly
-        "{}<div id=\"__perseus_content\">{}</div>",
+        "{}<div id=\"__perseus_content_initial\" class=\"__perseus_content\">{}</div>",
         &html_to_replace_double,
         &error_html
     );
